autoconf-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: bugs found


From: Akim Demaille
Subject: Re: bugs found
Date: 07 Jun 2002 11:51:04 +0200
User-agent: Gnus/5.0808 (Gnus v5.8.8) XEmacs/21.4 (Honest Recruiter)

Thanks for the report.  here is half of a fix.

Paul, ever seen something like this error?

configure:3004: checking for working GNU fnmatch
configure:3070: gcc -o conftest -g -O2   conftest.c  >&5
In file included from configure:3071:
/usr/local/include/fnmatch.h:38: ap_config.h: No such file or directory
configure:3070: $? = 1
configure: program exited with status 1
configure: failed program was:
#line 3070 "configure"
#include "confdefs.h"
#include <fnmatch.h>
#          define y(a, b, c) (fnmatch (a, b, c) == 0)
#          define n(a, b, c) (fnmatch (a, b, c) == FNM_NOMATCH)

#ifdef F77_DUMMY_MAIN
#  ifdef __cplusplus
     extern "C"
#  endif
   int F77_DUMMY_MAIN() { return 1; }
#endif
int
main ()
{
exit
           (!(y ("a*", "abc", 0)
              && n ("d*/*1", "d/s/1", FNM_PATHNAME)
              && y ("a\\bc", "abc", 0)
              && n ("a\\bc", "abc", FNM_NOESCAPE)
              && y ("*x", ".x", 0)
              && n ("*x", ".x", FNM_PERIOD)
              && y ("xxXX", "xXxX", FNM_CASEFOLD)
                    && y ("a++(x|yy)b", "a+xyyyyxb", FNM_EXTMATCH)
                    && n ("d*/*1", "d/s/1", FNM_FILE_NAME)
                    && y ("*", "x", FNM_FILE_NAME | FNM_LEADING_DIR)
                    && y ("x*", "x/y/z", FNM_FILE_NAME | FNM_LEADING_DIR)
                    && y ("*c*", "c/x", FNM_FILE_NAME | FNM_LEADING_DIR)));
  ;
  return 0;
}


The failure of the testsuite is due to the missing fnmatch.h, it's
fixed below.  I'm just very surprised by this very weird failure.

Index: ChangeLog
from  Akim Demaille  <address@hidden>

        * lib/autoconf/functions.m4 (AC_REPLACE_FUNC_FNMATCH): Typo,
        rename as...
        (AC_REPLACE_FNMATCH): this.
        * tests/mktests.sh (exclude_list): Exclude AC_REPLACE_FNMATCH,
        AC_FUNC_FNMATCH_GNU.

Index: lib/autoconf/functions.m4
===================================================================
RCS file: /cvsroot/autoconf/autoconf/lib/autoconf/functions.m4,v
retrieving revision 1.64
diff -u -u -r1.64 functions.m4
--- lib/autoconf/functions.m4 7 Jun 2002 09:30:24 -0000 1.64
+++ lib/autoconf/functions.m4 7 Jun 2002 09:49:06 -0000
@@ -409,13 +409,13 @@
 ])# _AC_LIBOBJ_FNMATCH
 
 
-# AC_REPLACE_FUNC_FNMATCH
-# -----------------------
-AC_DEFUN([AC_REPLACE_FUNC_FNMATCH],
+# AC_REPLACE_FNMATCH
+# ------------------
+AC_DEFUN([AC_REPLACE_FNMATCH],
 [_AC_FUNC_FNMATCH_IF([POSIX], [ac_cv_func_fnmatch_works],
                      [rm -f $ac_config_libobj_dir/fnmatch.h],
                      [_AC_LIBOBJ_FNMATCH])
-])# AC_REPLACE_FUNC_FNMATCH
+])# AC_REPLACE_FNMATCH
 
 
 # AC_FUNC_FNMATCH_GNU
Index: tests/acfunctions.at
===================================================================
RCS file: /cvsroot/autoconf/autoconf/tests/acfunctions.at,v
retrieving revision 1.8
diff -u -u -r1.8 acfunctions.at
--- tests/acfunctions.at 7 Jun 2002 07:17:54 -0000 1.8
+++ tests/acfunctions.at 7 Jun 2002 09:49:06 -0000
@@ -8,7 +8,6 @@
 AT_CHECK_MACRO([AC_FUNC_CLOSEDIR_VOID])
 AT_CHECK_MACRO([AC_FUNC_ERROR_AT_LINE])
 AT_CHECK_MACRO([AC_FUNC_FNMATCH])
-AT_CHECK_MACRO([AC_FUNC_FNMATCH_GNU])
 AT_CHECK_MACRO([AC_FUNC_FORK])
 AT_CHECK_MACRO([AC_FUNC_FSEEKO])
 AT_CHECK_MACRO([AC_FUNC_GETGROUPS])
@@ -30,7 +29,5 @@
 AT_CHECK_MACRO([AC_FUNC_STRTOD])
 AT_CHECK_MACRO([AC_FUNC_UTIME_NULL])
 AT_CHECK_MACRO([AC_FUNC_VPRINTF])
-AT_CHECK_MACRO([AC_REPLACE_FNMATCH_GNU])
-AT_CHECK_MACRO([AC_REPLACE_FUNC_FNMATCH])
 
 # Obsolete macros.
Index: tests/mktests.sh
===================================================================
RCS file: /cvsroot/autoconf/autoconf/tests/mktests.sh,v
retrieving revision 1.26
diff -u -u -r1.26 mktests.sh
--- tests/mktests.sh 7 Jun 2002 07:17:54 -0000 1.26
+++ tests/mktests.sh 7 Jun 2002 09:49:06 -0000
@@ -81,34 +81,48 @@
 #
 # - AC_CANONICALIZE, AC_PREFIX_PROGRAM, AC_PREREQ
 #   Need an argument.
+#
 # - AC_CHECK decl, file, func, header, lib, member, prog, sizeof, type
 #   Performed in the semantics tests.
+#
 # - AC_CONFIG
 #   They fail when the source does not exist.
 # - AC_FUNC_GETLOADAVG
 #   Requires a file that is not shipped with Autoconf.  But it should.
 # - AC_INIT
 #   AC_INIT includes all the AC_INIT macros.  Note that there is an
 #   infinite m4 recursion if AC_INIT it used twice.
+#
 # - AC_LANG*
 #   Heavily used by other macros.
+#
 # - AC_PATH_PROGS?, AC_F77_FUNC
 #   They produce `= val' because $1, the variable used to store the result,
 #   is empty.
+#
 # - AC_TRY, AC_.*_IFELSE, AC_RUN_LOG.
 #   Used in many places.
+#
 # - _AC_
 #   Internal macros are used elsewhere.
+#
 # - AC_OUTPUT
 #   Already tested by `AT_CHECK_MACRO'.
+#
 # - AC_FD_CC
 #   Is a number.
+#
 # - AC_PROG_CC, AC_C_(CONST|INLINE|VOLATILE), AC_PATH_XTRA
 #   Checked in semantics.
+#
 # - AC_CYGWIN, AC_CYGWIN32, AC_EMXOS2, AC_MING32, AC_EXEEXT, AC_OBJEXT
 #   AU defined to nothing.
+#
 # - AC_PATH_XTRA
 #   Checked in semantics.
+#
 # - AC_SYS_RESTARTABLE_SYSCALLS, AC_FUNC_WAIT3
 #   Obsolete, checked in semantics.
 #
@@ -117,7 +131,7 @@
 ^AC_CHECK_(DECL|FILE|FUNC|HEADER|LIB|MEMBER|PROG|SIZEOF|TOOL|TYPE)S?$
 ^AC_CONFIG
 ^AC_F77_FUNC$
-^AC_FUNC_GETLOADAVG$
+^AC_(FUNC_GETLOADAVG|REPLACE_FNMATCH|FUNC_FNMATCH_GNU)$
 ^AC_INIT
 ^AC_LANG
 ^AC_LINKER_OPTION$
@@ -81,34 +81,48 @@
 # - AC_CONFIG
 #   They fail when the source does not exist.
-# - AC_FUNC_GETLOADAVG
-#   Requires a file that is not shipped with Autoconf.  But it should.
+#
+# - AC_FUNC_GETLOADAVG, AC_REPLACE_FNMATCH, AC_FUNC_FNMATCH_GNU
+#   Require a file that is not shipped with Autoconf.  But it should.
+#
 # - AC_INIT
 #   AC_INIT includes all the AC_INIT macros.  Note that there is an



reply via email to

[Prev in Thread] Current Thread [Next in Thread]